@@ -17,7 +17,9 @@ class FunctionMixin():
 
     \*args, \*\*kwargs :
         Arguments and keyword arguments which the Function model will pass 
-        into its `func` when called.
+        into its `func` when called. The `FunctionMixin` constructor will not
+        override arguments and keyword arguments if they have already been
+        set.
 
     Attributes
     ----------
@@ -83,8 +85,30 @@ class FunctionMixin():
 
     def __init__(self, func, *args, **kwargs):
         self.func = func
-        self.args, self.kwargs = list(args), kwargs
+        # note that args or kwargs may have already been set
+        self.args = self.args or list(args)
+        self.kwargs = self.kwargs or kwargs
         super().__init__()
+
+    def set(self, func, *args, **kwargs):
+        """
+        Set the function, arguments, and keyword arguments.
+
+        Parameters
+        ----------
+        func : callable or None, default=None
+            The function which the Function model will execute when called.
+
+        \*args, \*\*kwargs :
+            Arguments and keyword arguments which the Function model will pass 
+            into its `func` when called.
+
+        Returns
+        -------
+        self : sqlalchemy_function.FunctionMixin
+        """
+        self.func, self.args, self.kwargs = func, list(args), kwargs
+        return self
     
     def __call__(self):
         """
